# The Sprint Mechanics Assessment Score

## A Qualitative Screening Tool for the In-field Assessment of Sprint Running Mechanics

Christopher Bramah,\* \[yz\] PhD, Jonas Tawiah-Dodoo, \[§\] BSc, MSc,

### Samantha Rhodes, \[yz\]\[||\] BSc, MSc, Joshua D. Elliott, \[z\]\[||\]\[{\] BSc, MSc, and Thomas Dos’Santos, \[#\] \*\* PhD

Investigation performed at School of Health & Society, University of Salford, Salford,
Manchester, UK

Background: Qualitative movement screening tools provide a practical method of assessing mechanical patterns associated
with potential injury development. Biomechanics play a role in hamstring strain injury and are recommended as a consideration
within injury screening and rehabilitation programs. However, no methods are available for the in-field assessment of sprint running mechanics associated with hamstring strain injuries.

Purpose: To investigate the intra- and interrater reliability of a novel screening tool assessing in-field sprint running mechanics
titled the Sprint Mechanics Assessment Score (S-MAS) and present normative S-MAS data to facilitate the interpretation of performance standards for future assessment uses.

Study Design: Cohort study (diagnosis); Level of evidence, 3.

Methods: Maximal sprint running trials (35 m) were recorded from 136 elite soccer players using a slow-motion camera. All videos
were scored using the S-MAS by a single assessor. Videos from 36 players (18 men and 18 women) were rated by 2 independent
assessors blinded to each other’s results to establish interrater reliability. One assessor scored all videos in a randomized order 1
week later to establish intrarater reliability. Intraclass correlation coefficients (ICCs) based on single measures using a 2-way
mixed-effects model, with absolute agreement with 95% CI and kappa coefficients with percentage agreements, were used to
assess the reliability of the overall score and individual score items, respectively. T-scores were calculated from the means
and standard deviations of the male and female groups to present normative data values. The Mann-Whitney U test and the Wilcoxon signed-rank test were used to assess between-sex differences and between-limb differences, respectively.

Results: The S-MAS showed good intrarater (ICC, 0.828 \[95% CI, 0.688-0.908\]) and interrater (ICC, 0.799 \[95% CI, 0.642-0.892\])
reliability, with a standard error of measurement of 1 point. Kappa coefficients for individual score items demonstrated moderate
to substantial intra- and interrater agreement for most parameters, with percentage agreements ranging from 75% to 88.8% for
intrarater and 66.6% to 88.8% for interrater reliability. No significant sex differences were observed for overall scores, with mean
values of 4.2 and 3.8 for men and women, respectively (P = .27).

Conclusion: The S-MAS is a new tool developed for assessing sprint running mechanics associated with lower limb injuries in
male and female soccer players. The reliable and easy-to-use nature of the S-MAS means that this method can be integrated
into practice, potentially aiding future injury screening and research looking to identify athletes who may demonstrate mechanical
patterns potentially associated with hamstring strain injuries.

Keywords: biomechanics; hamstring; movement quality; qualitative screening; rehabilitation; screening; soccer

Hamstring strain injuries (HSIs) are the most common
injuries affecting team-based sports, accounting for up to
24% of injuries in soccer. \[12\] The primary mechanism of
HSI appears to be during maximal velocity sprint running,
with up to 48% of all HSIs reported to occur at this time
point. \[16\] Although several risk factors exist for HSIs (ie,

The American Journal of Sports Medicine
1–9

DOI: 10.1177/03635465241235525
� 2024 The Author(s)

age, previous injury, eccentric hamstring strength, and
muscle architecture), \[15\] recent qualitative studies highlight
that practitioners and coaches believe sprint running biomechanics are 1 of a variety of factors that may influence
injury development. \[14,22\] With specific regard to sprint running mechanics, an overstride gait pattern, reduced lumbopelvic control, anterior pelvic tilt, and excessive backside
mechanics are some of the most common kinematic features thought to influence the risk of HSIs. \[22\]

Several investigations provide empirical data to support
the association between sprint mechanics and HSI occurrence. \[13,24,42,43\] Schuermans et al \[43\] reported that 4 soccer

1

2 Bramah et al The American Journal of Sports Medicine

players who sustained an HSI demonstrated increased
anterior pelvic tilt during the swing phase of running
when compared with controls, while additional studies
have reported players who sustained an HSI displayed features including increased trunk-side flexion, \[24\] altered
trunk muscle activity, \[13,42\] and increased trunk flexion
angles at touch-down. \[41\] These kinematic features may
increase hamstring stretch, resulting in greater tissue
strain at key phases of the gait cycle when muscle forces
are high. \[5\]

Based on the association between biomechanics and HSI,
authors have suggested that sprint running mechanics and
subsequent technique modification should be considered
within injury prevention and rehabilitation programs. \[11,28\]

However, current assessment methods are generally
restricted to 3-dimensional (3D) motion capture technology
(3D MoCap). Although 3D MoCap is considered the gold
standard of biomechanical assessments, such technology is
costly and time-consuming, often restricted to laboratory
spaces. Consequently, it is not feasible for practitioners to
conduct in-field assessments of sprint running mechanics,
particularly for screening large numbers of athletes in
team-based sports. Therefore, practitioners are currently
unable to identify and assess players who may demonstrate
suboptimal movement patterns that could potentially influence tissue stress and strain and possible HSIs, and they
are also unable to evaluate the effectiveness of interventions
targeting sprint running mechanics.
Qualitative movement screening tools using 2-dimensional video cameras offer a practical approach to in-field
movement assessment, identifying movement quality deficits linked to potential injury occurrence. For example, several methods have been developed across a variety of
activities—including the Landing Error Scoring System
(LESS), \[38\] the Cutting Movement Assessment Score
(CMAS), \[10\] and the qualitative analysis of single-leg loading. \[19\] These tools have proved to be reliable methods of
movement assessment that can be easily integrated into
practice and utilized in the injury risk screening, mitigation, and rehabilitation process. \[9,20,21\] However, these
assessment tools are designed to identify mechanical patterns associated with non-contact knee injuries. To date,
there are no field-based screening methods for assessing
sprint running mechanics associated with HSIs.
Based on the association between sprint running
mechanics and HSI, a qualitative movement screening
tool may prove to be a practical approach to evaluating

sprint running mechanics which may influence HSI. The
creation of such a tool could ultimately assist in large
mass injury screening and rehabilitation processes,
enabling practitioners to identify those who demonstrate
mechanical patterns associated with potential HSI,
whereby individualized gait interventions and technique
modification programs can be developed.
Therefore, the primary aim of this study was to investigate the intra- and interrater reliability of a novel, easy-touse, in-field method of assessing sprint running mechanics
associated with HSI—the Sprint Mechanics Assessment
Score (S-MAS). The secondary aim was to present normative benchmarking data from a larger data set of participants to aid future interpretation of S-MAS values.
Based on reliability results of previous qualitative screening tools, \[10,38\] it was hypothesized that the S-MAS would
demonstrate good to excellent intra- and interrater
reliability.

METHODS

Participants

A total of 136 elite soccer players (54 women and 82 men)
were recruited from 10 clubs (7 male and 3 female) in the
English Football League. Participants were classified as
either tier 3 (highly trained/national level) or tier 4 (elite/
international level) according to a recent participant classification framework proposed by McKay et al \[30\] ; participant
characteristics are presented in Table 1. A subset of 36 participants (18 women and 18 men) was used to establish the
intra- and interrater reliability of the S-MAS (Table 1). The
reliability sample size was based on a previous power calculation described by Bonett \[1\] for an expected level of reliability of 0.85, precision of 0.1, confidence intervals set to
95%, and a total of 2 raters, indicating that 31 participants
were required to achieve sufficient statistical power. All
participants were injury-free and cleared for full training
and competition before data collection; participants were
excluded from data analysis if they had a recent injury or
surgery within the past 12 months. Goalkeepers were
also excluded from the analysis because of their lack of regular exposure to sprint running. Ethical approval was
granted by the local ethics committee, and all participants
provided written informed consent before participation.

\*Address correspondence to Christopher Bramah, PhD, School of Health & Society, University of Salford, Allerton Building, Frederick Road Campus,
Salford, Manchester, M6 6PU, UK (email: <c.a.bramah@salford.ac.uk>) (Social Media: @chrisbramah).
ySchool of Health & Society, University of Salford, Salford, Manchester, UK.
zManchester Institute of Health & Performance, Manchester, UK.
§Speedworks Training, Stamford, UK.
||Nuffield Health, Manchester Institute of Health & Performance, UK.
{Research Institute for Sport and Exercise, University of Canberra, Canberra, Australia.

# Department of Sport & Exercise Sciences, Manchester Metropolitan University, Manchester, UK.

\*\*Manchester Institute of Sport, Metropolitan University, Manchester, UK.
Submitted August 4, 2023; accepted January 3, 2024.
The authors declared that they have no conflicts of interest in the authorship and publication of this contribution. AOSSM checks author disclosures
against the Open Payments Database (OPD). AOSSM has not conducted an independent investigation on the OPD and disclaims any liability or responsibility relating thereto.

AJSM Vol. XX, No. X, XXXX S-MAS: A Qualitative Screening Tool 3

TABLE 1
Participant Characteristics \[a\]

All Data Reliability Data

Men (n = 82) Women (n = 54) Men (n = 18) Women (n = 18)

Age, y 22 (4.5) 24.1 (4.5) 24.6 (5.4) 23.7 (4.9)
Mass, kg 78.6 (7.8) 62.2 (6.2) 77.8 (7.9) 60.9 (8.2)
Height, cm 182.6 (5.6) 166.3 (6.2) 181.2 (4.9) 163.7 (5.5)
Maximal running speed, m/sec 8.5 (1.2) 7 (0.6) 8.7 (1.3) 6.5 (0.5)

aValues are presented as mean (SD).

Figure 1. Visual representation of phases of the sprint cycle. MVP, maximal vertical projection.

Data Collection

All participants completed 2 maximum-effort 35-m sprint
running trials, which were recorded using a slow-motion
camera sampling at 240 fps (iPhone 13 pro; Apple). Data
were collected between June 2022 and September 2023.
Two pairs of photocell timing gates (Witty Photocells; Micrograte), placed at approximately hip height, were positioned
across the capture volume between 25 and 30 m to monitor
maximal running speed. The 25- to 30-m section was
selected as this marks the end of the sprint transition phase,
reflecting maximal speed running mechanics— particularly
for team sport athletes who attain maximum speed earlier
than track sprinters. \[35\] The camera was positioned on a tripod at a height of 0.8 m and a distance of 7 m perpendicular
to the capture volume. Participants completed a standardized raise, activate, mobilize, potentiate warm-up led by
individual club sports science teams before completing 2
maximum-effort sprint running trials. The warm-up consisted of low-intensity jogging, dynamic mobility, and running drills, followed by single progressive running strides
at 80% and 90% of maximum effort and took 10 to 15
minutes. All running trials were completed with participants wearing their own sport-specific footwear on a synthetic artificial field turf or grass football pitch. A
subgroup of 25 male participants completed 3 maximumeffort running trials. The additional maximum-effort running trial allowed for data collection of 2 videos recorded
from the same side, subsequently used to determine intertrial reliability of the S-MAS.

S-MAS Tool

The S-MAS is a 12-item qualitative movement screening
tool assessing the overall movement quality of an individual’s sprint running mechanics (Table 2) (see also the Appendix, available in the online version of this article). Using
a slow-motion video, sprint running trials were segmented
into phases of the gait cycle similar to those described in
the ALTIS Kinogram method \[32\] (Figure 1 and Table 2).
Movement patterns were then evaluated and rated against
12 criteria using a dichotomous scoring system for the presence (1 point) or absence (0 point) of select kinematic features. Scores were summed with a total score of

0 indicating optimal mechanics and 12 suboptimal, with
higher scores generally representative of poorer technique.
The score was developed after a 3-step process. First,
individual items forming the score were selected based on
findings from published qualitative investigations that
explored the opinions of coaches and practitioners on kinematic features influencing HSIs. \[22\] Second, a literature
review was conducted to identify parameters with a mechanistic link influencing hamstring tissue stress/strain and/
or previous published associations with HSI. \[2\] This led to
an initial draft of the S-MAS, with operational definitions
used to visualize parameters based on values published
in previous literature detailing maximal velocity sprint
running mechanics. \[29,44\] Finally, separate consultations
were conducted with practitioners and coaches to establish
agreements or disagreements with any of the included
parameters and refine operational definitions of the

4 Bramah et al The American Journal of Sports Medicine

TABLE 2
The Sprint Mechanics Assessment Score \[a\]

Score: Yes = 1, No = 0

Phase Parameter & Description

Left Right

Contralateral toe-off

The point immediately
before the contralateral

foot leaving the ground

Contralateral toe-off Trailing limb extension
The point immediately Does the athlete appear to be in excessive extension?
before the contralateral This may be characterized by the trailing hip oriented at �45� from the
foot leaving the ground vertical, combined with a fully extended knee.

MVP Back kick

Midpoint between toe- Is the heel of the trailing limb above the calf of the trailing leg?
off and touch-down; Shin should not be higher than parallel with the floor.
pelvis is at its highest Trunk and pelvic rotation
point in the flight phase Does the athlete appear to rotate excessively through the trunk?

MVP Back kick

Midpoint between toe- Is the heel of the trailing limb above the calf of the trailing leg?
off and touch-down; Shin should not be higher than parallel with the floor.
pelvis is at its highest Trunk and pelvic rotation
point in the flight phase Does the athlete appear to rotate excessively through the trunk?

This may appear as large arm movements or trunk twisting, with the upper
arm and shoulder visible on the far side of the body.
Late swing Thigh separation
The point of maximal Is the knee of the trailing leg behind the gluteal muscles?
knee extension during
the swing phase

MVP to late swing Lumbar extension/anterior pelvic tilt
At any point between MVP and late swing, does the athlete appear to be in
anterior pelvic tilt or lumbar extension?
This may look like excessive lower back arching, elevated chest, or ‘‘bum
behind the body.’’
Touch-down Forward lean

Point of first contact Does athlete appear to have an increased forward lean? This may look .15�
with the ground if a line is drawn from the vertical compared with one from the greater

Thigh separation
Is the knee of the trailing leg behind the gluteal muscles?

Touch-down Forward lean

Point of first contact Does athlete appear to have an increased forward lean? This may look .15�
with the ground if a line is drawn from the vertical compared with one from the greater

trochanter to the C7 vertebra.

Lumbar extension/anterior pelvic tilt
Does there look to be an increase in anterior pelvic tilt or lumbar extension?
This may look like excessive lower back arching or ‘‘bum behind the body.’’
Thigh separation
Is the gap between the thighs .20� or the trailing knee behind the back?
Foot contact vs CoM distance

A line is drawn horizontally from the position of foot contact to the CoM.
Is there space for another foot?
Shin angle
Does the shin look to be extended?

This may appear as an ankle joint center in front of the knee.
Foot inclination

Is there a visible gap between the forefoot and the floor, or the heel and the
floor (excessive heel strike or forefoot strike)?
Midstance Vertical collapse/midstance collapse
The point where pelvis Is there increased knee flexion/ankle dorsiflexion? This may look like the
is positioned directly athlete is ‘‘sinking’’ into the stride, ‘‘sitting down,’’ or the knee is
over the ankle joint translating over the toes with the foot flat.

Midstance Vertical collapse/midstance collapse
The point where pelvis Is there increased knee flexion/ankle dorsiflexion? This may look like the
is positioned directly athlete is ‘‘sinking’’ into the stride, ‘‘sitting down,’’ or the knee is
over the ankle joint translating over the toes with the foot flat.

Total score

aCoM, center of mass; MVP, maximal vertical projection.

criteria. This led to the final S-MAS detailed in Table 2 and
the Appendix (available online).

Intra- and Interrater Reliability

For the reliability assessment, 2 raters first attended a 2hour training session on how to use the S-MAS. Raters
included 1 physical therapist (C.B.) and 1 strength and
conditioning coach (T.D.S), both with .10 years of

experience in their respective field and a PhD in biomechanics. The 2-hour training session included a discussion
of score items and definitions and 3 practice trials where
videos were first independently scored, followed by a discussion of agreements and disagreements in ratings. Videos were viewed by raters in Kinovea (Version 0.9.5 for
Windows) software, which allowed videos to be played at
various speeds and frame by frame. Gait phases were identified in accordance with descriptors provided on the SMAS, with practitioners permitted to move frames forward

AJSM Vol. XX, No. X, XXXX S-MAS: A Qualitative Screening Tool 5

Figure 2. Intra- and interrater kappa coefficient for individual
Sprint Mechanics Assessment Score (S-MAS) parameters.
CoM, center of mass. V, versus.

and backward to help identify the parameters. All practice
videos were excluded from the final reliability testing.
After the training session, both raters separately scored
all 36 videos against the S-MAS. Two weeks later, 1 rater
(T.D.S.) scored all videos again in a randomized order,
blinded to original scores, similar to methods outlined in
previous studies. \[36,38\] Screening of 1 video trial took ~2
minutes.

Statistical Analysis

Statistical tests were performed in SPSS Version 26 (IBM).
S-MAS values were first analyzed for data normality and
homogeneity of variances using the Shapiro-Wilk test
and the Levine test. Because of the non-normal distribution of data, the Mann Whitney U test was used to assess
between-sex differences, and the Wilcoxon signed-rank
test was used to assess between-limb differences in
S-MAS values. One-way analysis of variance was used to
evaluate differences between playing positions, with positions separated into central defenders, wide defenders,
central midfielders, wide midfielders, and forwards.
T-scores were calculated to establish normative bench
marks for individual profiling, as described in previous publications, to facilitate practical use and interpretation of
S-MAS values. \[31,45\] Sample sizes of 50 to 85 have been suggested as the minimum required to achieve stable means
and standard deviations for establishing normative data. \[39\]

z scores were initially calculated using the following formula: z = (S-MAS value – group mean)/group SD. z scores
were converted to T-scores using the formula T = (z x 10)
1 50. T-scores of 50 are equivalent to the mean value,
scores of �60 are 1 SD above the mean, and scores of below
�40 are 1 SD below the mean. T-scores were interpreted as
\\40 excellent, �40 to �45 good, .45 to �55 average, .55 to
�60 poor, .60 to �80 very poor, and .80 extremely poor. \[31\]

Intrarater, interrater, and intertrial reliability of the
overall S-MAS was assessed using the intraclass

Figure 3. Intra- and interrater percentage agreement for
individual Sprint Mechanics Assessment Score (S-MAS)
parameters. CoM, center of mass. V, versus.

correlation coefficient (ICC) based on single measures
using a 2-way mixed-effects model with absolute agreement with 95% CI in accordance with methods outlined
by Koo and Li. \[25\] Standard error of measurement (SEM)
was calculated as SD\*O(1-ICC). ICC values of \\0.5, 0.5
to 0.75, 0.76 to 0.9, and .0.9 were interpreted as poor,
moderate, good, and excellent, respectively. \[25\] Reliability
of individual items on the S-MAS was assessed using the
Cohen kappa statistic and percentage agreements as
described in previous literature. \[6\] Cohen kappa values
were interpreted as follows: \\0, poor; 0 to 0.20, slight;
0.21 to 0.40, fair; 0.41 to 0.60, moderate; 0.61 to 0.80, substantial; 0.81 to 1, almost perfect. \[27\] Percentage agreements
were interpreted as follows: �50%, poor; 51% to 79%, moderate; and �80%, excellent. \[36\]

RESULTS

ICC values for intrarater and interrater reliability showed
good reliability with values of 0.828 (95% CI, 0.688-0.908)
and 0.799 (95% CI, 0.642-0.892), respectively, with an
SEM of 1 point. Based on kappa coefficients for individual
items, 11 out of 12 parameters demonstrated moderate to
substantial intrarater reliability, and 9 out of 12 demonstrated moderate to significant interrater reliability (Figure 2). Percentage agreements ranged from 75% to 88.8%
for intrarater and 66.6% to 88.8% for interrater reliability,
demonstrating moderate to excellent agreement for all
parameters (Figure 3). For intertrial reliability, the mean
S-MAS value for trial 1 was 4.1 (SD, 2.3) and for trial 2,
4 (SD, 2). The ICC was 0.74 (95% CI, 0.492-0.877), with
an SEM of 1 point.
No significant differences were observed in S-MAS scores
between male and female soccer players, with mean values
of 4.2 (SD, 2.6) and 3.8 (SD, 2.5), respectively (P = .27). Significant between-limb differences were observed between

right (mean, 4.5 \[SD, 2.7\]) and left limbs (mean, 4 \[SD,
2.7\]) (P \\ .01 \[95% CI, 0.09-0.81\]). No significant differences

6 Bramah et al The American Journal of Sports Medicine

Figure 4. Box plots for S-MAS values based on playing position. The solid line within the box depicts the median value,
the top and bottom of the box indicate the interquartile
range, the whiskers depict the minimum and maximum values, and the cross indicates the mean value. S-MAS, Sprint
Mechanics Assessment Score.

were observed between playing position (P = .664) (Figure
4). Using T-scores and benchmarking, S-MAS descriptors
are presented in Figure 5.

DISCUSSION

The primary aim of this study was to investigate the intraand interrater reliability of a novel in-field method of
assessing sprint running mechanics associated with
HSIs, the S-MAS. As hypothesized, results highlight that
the S-MAS has good intra- and interrater reliability, with
no significant differences observed in mean scores between
male and female soccer players, or playing positions.
Therefore, the findings of the present study indicate that
the S-MAS is a reliable tool that can be used for in-field
assessment of sprint running mechanics in both male
and female populations.
It is widely acknowledged that the interaction between
multiple factors influences HSI development. \[3\] Eccentric
hamstring strength, muscle architecture, material properties, age, high-speed sprint running exposure, fixture congestion, fatigue, recovery, and training environment are
some of the many factors acknowledged by coaches, practitioners, and research to play a role in HSI. \[3,14,15\] In addition,
biomechanical factors are believed to play a role in developing HSIs within team sports. \[14,22\] Although data from both
prospective and retrospective investigations \[8,43\] support
the associations between the two, research primarily utilizes 3D MoCap. This technology is undoubtedly the gold
standard of biomechanical assessments; however, it lacks
clinical utility in-field and is not conducive for large mass
athlete screening. The costly and time-consuming nature
of 3D MoCap limits the ability to recruit large sample sizes
in research studies and restricts the practical assessment of
players in team sports settings. Addressing this limitation,

Figure 5. Normative benchmarking for S-MAS interpretation
based on T-Scores. S-MAS, Sprint Mechanics Assessment
Score.

the S-MAS offers a practical alternative to 3D MoCap by
simply using the high-speed recording capabilities of a smart
device, which is a common default feature of most tablet and
smartphone technology, as well as free video-viewing software. Thus, it allows practitioners and coaches to quickly
assess sprint running mechanics of players and teams,
and identify those who may demonstrate kinematic patterns associated with HSIs.

Although some literature supports the association
between isolated biomechanical parameters and HSIs,
this relationship can often be conflicting. \[24,43\] Because muscle injuries occur as a result of the interaction between
stress and strain, \[23\] it seems logical that a combination of
mechanical patterns contributes to the occurrence of
HSIs. This is reflected in multiple case reports where
injury onset was associated with various mechanical features thought to influence overall tissue strain. \[18,41\]

The S-MAS utilizes a composite score that aims to
reflect the collective contribution of multiple biomechanical parameters on potential HSI risk. This is similar to
existing movement assessment tools such as the LESS \[38\]

and CMAS \[10\] in relation to knee joint loads associated
with anterior cruciate ligament injury risk. The composite
score approach intends to shift practitioner focus away
from single parameters and quantify the overall severity

AJSM Vol. XX, No. X, XXXX S-MAS: A Qualitative Screening Tool 7

of gait, building confidence in whether observed mechanical patterns are sufficient to influence injury.
The composite nature of the S-MAS is important from
a reliability perspective, as individual items often have
lower reliability than the total score. In a previous study
investigating the reliability of a qualitative analysis for
endurance running, 5 parameters out of 15 demonstrated
fair to poor interrater reliability, \[40\] indicating potential
variations in the interpretation of isolated kinematic variables. In the present study, greater interrater reliability
was observed; nonetheless, 3 parameters (back kick, trunk
rotation, and trailing leg extension) still showed poor to
fair interrater agreement based on kappa coefficients (see
Figure 2). These parameters showed moderate percentage
agreements (see Figure 3). Conversely, the overall S-MAS
values demonstrate good inter- and intrarater reliability.
This suggests that the overall score can be more confidently relied upon when identifying those who may demonstrate potential ‘‘high-risk’’ movement patterns and when
evaluating the response to interventions.
While acknowledging the importance of the overall
score, there is still potential value gained from interpreting
individual score items. Individual score items represent
different aspects of sprint running mechanics and can aid
practitioners in identifying specific mechanical factors contributing to the overall movement quality. For example,
within the S-MAS, score items of ‘‘back-kick,’’ ‘‘thigh-separation angle,’’ and ‘‘trailing leg extension’’ represent backside running mechanics. \[29\] In contrast, other items
represent altered lumbopelvic control and/or overstride
mechanics. Identifying these subcomponents allows for
developing specific, tailored movement interventions that
have been proven capable of modifying movement patterns
associated with HSIs. \[33,34\] Therefore, both the composite
score and the individual items play complementary roles
in using the S-MAS through identifying potentially
‘‘higher-risk’’ individuals, development of targeted interventions, and evaluation of overall change.
In the present study, normative ranges were calculated
using T-scores from the entire data set to aid in the clinical
interpretation of S-MAS values. This approach is commonly used for normative data benchmarking in sports
performance and injury screening \[10,38\] and is similar to
methods used for movement assessment scores, such as
the LESS and CMAS. Based on the T-scores, S-MAS values
of �1 were considered excellent, 2 as good, 3 to 5 as average, 6 as poor, �7 as very poor, and 12 as extremely
poor. Across other movement assessment scores, Padua
et al \[38\] used quartile ranges to separate scores on the
LESS into severity categories, later reporting values .5
(considered moderate to poor) to be associated with
a greater incidence of future anterior cruciate ligament
injuries. \[37\] Similarly, Dos’Santos et al \[10\] reported CMAS
scores .7 to be associated with greater knee joint loading
parameters compared with scores of �3. Therefore, using
composite scores and normative ranges may aid the clinical
interpretation of S-MAS values, assisting practitioners in
identifying those who demonstrate potential higher-risk
movement patterns and benefit from targeted gait interventions. However, it is important to be cautious with

this interpretation, as further work is required to establish
the association between the S-MAS and HSIs.

Comparing results from the present study with those of
previous authors, ICC values for the reliability of the
S-MAS appear similar to other established movement
assessment scores. The LESS score \[38\] has been shown to

have ICC values of 0.910 and 0.840 for intra- and interrater reliability, while the CMAS \[10\] has shown ICC values
of 0.946 and 0.690. This is similar to the present scores of
0.828 and 0.799 for intra- and interrater reliability. The
good reliability of the S-MAS could be attributed to several
factors. First, consistent with previous researchers, the 2
raters were provided with a training session before scoring
videos and had a background in biomechanics. \[10,38\] It is
unknown whether practitioner training improves reliability, \[26\] but it potentially allows for consistency in the application of the S-MAS and has been anecdotally suggested to
improve interrater reliability. \[38,47\] Second, the S-MAS utilizes dichotomous ratings for individual items and clear
definitions aiding the visualization of parameters. The
use of dichotomous ratings has been shown to improve
both within and between practitioner agreement in the
visual assessment of movement patterns, removing ambiguity in identifying specific mechanical features. \[4,47\]

Finally, the S-MAS utilizes predominantly sagittal plane
movements, which are more pragmatic for data capture
and allow easier screening against the established
S-MAS criteria. Therefore, the combined use of practitioner training, along with clear assessment criteria and
a dichotomous rating system, may contribute to the overall
reliability of the S-MAS.
Even though no significant differences were observed
between male and female soccer players, significant
between-limb differences were found when comparing
right and left limbs. However, the mean difference of
0.45 and 95% CI of 0.09 to 0.81 are less than the standard
measurement error of the SEM of 1 point for the S-MAS.
Therefore, the between-limb differences fall within the
range that can be considered because of the intertrial variability of kinematic patterns. For future practical interpretation of differences in S-MAS scores, it is
recommended to ensure that differences exceed the stan
dard measurement error for differences to be considered
potentially meaningful.

LIMITATIONS

The present study has some limitations that need to be
acknowledged. One is that there were only 2 raters, and
both could be considered expert raters with .10 years of
experience in biomechanics and their respective professions. That said, the rater used for the intrarater reliability
could be considered a novice user of the score. Although
involved in the S-MAS development process, he had no
experience utilizing the score before the reliability testing.
Although a previous study by Whatman et al \[48\] suggested
that more experienced raters demonstrate greater intraand interrater reliability when visually scoring movement

8 Bramah et al The American Journal of Sports Medicine

compared with novices, these findings are equivocal. Several further studies have reported good to excellent intraand intertester reliability among novices compared with
experienced raters, \[7,17,46\] with 1 study utilizing the LESS
(a composite score similar to the current work), reporting
excellent intra- and intertester reliability of the LESS
with ICCs of 0.835 among novice raters. \[36\] Therefore, we
would hypothesize similar findings when comparing reliability of the S-MAS between larger groups of practitioners, particularly if training is conducted to
standardize the use of the S-MAS score. However, we
acknowledge that future work should consider evaluating
the intertester reliability of the S-MAS between novice/
inexperienced practitioners and practitioners of different
professions (ie, sports scientists, physicians, coaches, etc).
Another limitation is that the reliability was assessed
using a single running trial. This was because of the pragmatic nature of collecting repeat maximal velocity sprint
running trials in elite soccer players, where the collection
of multiple trials is not feasible in many instances. Consequently, this may reduce the overall reliability when using
ICC single measures. However, despite this, ICC values
were still good; nonetheless, they may potentially be
improved if S-MAS scores are averaged across multiple
sprint trials. Therefore, this should be a consideration for
future research and practical use of the S-MAS.
Finally, the data presented in the present study pertain
to those who were injury-free at the time of testing. Further
work is required to investigate whether the S-MAS differs
between those with recent HSIs and whether there are associations to future injury development.

CONCLUSION

The present study highlights that the S-MAS is a reliable
tool for the in-field assessment of sprint running mechanics in both male and female populations. The easy-to-use
nature of the S-MAS means that it can be easily integrated
into practice to permit large mass screening of athletes
from the community to the elite level. The presented normative benchmarking values may aid in the applied use
of the S-MAS, facilitating the identification of those who
demonstrate potential higher-risk sprint running mechanics and may benefit from interventions targeted toward
optimizing movement quality.

ORCID iDs

Christopher Bramah <https://orcid.org/0000-0003-36449873>
Samantha Rhodes <https://orcid.org/0000-0001-7121-1911>

REFERENCES

1. Bonett DG. Sample size requirements for estimating intraclass correlations with desired precision. Stat Med. 2002;21(9):1331-1335.
   doi:10.1002/sim.1108

1. Bramah C, Mendiguchia J, Dos’Santos T, Morin JB. Exploring the
   role of sprint biomechanics in hamstring strain injuries: a current
   opinion on existing concepts and evidence. Published online September 19, 2023. Sports Med. doi:10.1007/s40279-023-01925-x

1. Buckthorpe M, Wright S, Bruce-Low S, et al. Recommendations for
   hamstring injury prevention in elite football: translating research into
   practice. Br J Sports Med. 2019;53(7):449-456. doi:10.1136/
   bjsports-2018-099616

1. Chmielewski TL, Hodges MJ, Horodyski M, Bishop MD, Conrad BP,
   Tillman SM. Investigation of clinician agreement in evaluating movement quality during unilateral lower extremity functional tasks: a comparison of 2 rating methods. J Orthop Sports Phys Ther.
   2007;37(3):122-129. doi:10.2519/jospt.2007.2457

1. Chumanov ES, Heiderscheit BC, Thelen DG. The effect of speed and
   influence of individual muscles on hamstring mechanics during the
   swing phase of sprinting. J Biomech. 2007;40(16):3555-3562.
   doi:10.1016/j.jbiomech.2007.05.026

1. Cohen J. A coefficient of agreement for nominal scales. Educ Psychol
   Meas. 1960;20(1):37-46. doi:10.1177/001316446002000104

1. Crossley KM, Zhang WJ, Schache AG, Bryant A, Cowan SM. Performance on the single-leg squat task indicates hip abductor muscle
   function. Am J Sports Med. 2011;39(4):866-873. doi:10.1177/

0363546510395456

8. Daly C, Persson UM, Twycross-Lewis R, Woledge RC, Morrissey D.
   The biomechanics of running in athletes with previous hamstring
   injury: a case-control study. Scand J Med Sci Sports.
   2016;26(4):413-420. doi:10.1111/sms.12464

1. Dos’Santos T, McBurnie A, Comfort P, Jones PA. The effects of sixweeks change of direction speed and technique modification training
   on cutting performance and movement quality in male youth soccer
   players. Sports (Basel). 2019;7(9):205. doi:10.3390/sports7090205

1. Dos’Santos T, McBurnie A, Donelon T, Thomas C, Comfort P, Jones
   PA. A qualitative screening tool to identify athletes with ‘‘high-risk’’
   movement mechanics during cutting: the cutting movement assessment score (CMAS). Phys Ther Sport. 2019;38:152-161. doi:10.1016/
   j.ptsp.2019.05.004

1. Edouard P, Mendiguchia J, Guex K, et al. Sprinting: a key piece of
   the hamstring injury risk management puzzle. Br J Sports Med.
   2023;57(1):4-6. doi:10.1136/bjsports-2022-105532

1. Ekstrand J, Bengtsson H, Walde´ n M, Davison M, Khan KM, Ha¨ gglund M. Hamstring injury rates have increased during recent seasons and now constitute 24% of all injuries in men’s professional
   football: the UEFA Elite Club Injury Study from 2001/02 to 2021/22.
   Br J Sports Med. 2022;57(5):292-298. doi:10.1136/bjsports-2021
   105407

1. Franettovich Smith MM, Bonacci J, Mendis MD, Christie C, Rotstein
   A, Hides JA. Gluteus medius activation during running is a risk factor
   for season hamstring injuries in elite footballers. J Sci Med Sport.
   2017;20(2):159-163. doi:10.1016/j.jsams.2016.07.004

1. Freeman BW, Talpey SW, James LP, Young WB. Sprinting and hamstring strain injury: beliefs and practices of professional physical performance coaches in Australian football. Phys Ther Sport.
   2021;48:12-19. doi:10.1016/j.ptsp.2020.12.007

1. Green B, Bourne MN, van Dyk N, Pizzari T. Recalibrating the risk of
   hamstring strain injury (HSI): a 2020 systematic review and metaanalysis of risk factors for index and recurrent hamstring strain injury
   in sport. Br J Sports Med. 2020;54(18):1081-1088. doi:10.1136/
   bjsports-2019-100983

1. Gronwald T, Klein C, Hoenig T, et al. Hamstring injury patterns in professional male football (soccer): a systematic video analysis of 52
   cases. Br J Sports Med. 2022;56(3):165-171. doi:10.1136/bjsports
   2021-104769

1. Harris-Hayes M, Steger-May K, Koh C, Royer NK, Graci V, Salsich
   GB. Classification of lower extremity movement patterns based on
   visual assessment: reliability and correlation with 2-dimensional
   video analysis. J Athl Train. 2014;49(3):304-310. doi:10.4085/10626050-49.2.21

1. Heiderscheit BC, Hoerth DM, Chumanov ES, Swanson SC, Thelen
   BJ, Thelen DG. Identifying the time of occurrence of a hamstring

AJSM Vol. XX, No. X, XXXX S-MAS: A Qualitative Screening Tool 9

strain injury during treadmill running: a case study. Clin Biomech
(Bristol, Avon). 2005;20(10):1072-1078. doi:10.1016/j.clinbiomech

.2005.07.005

19. Herrington L, Munro A. A preliminary investigation to establish the criterion validity of a qualitative scoring system of limb alignment during
    single leg squat and landing. J Exerc Sports Orthop. 2014;1(2):1-6.
    doi:10.15226/2374-6904/1/3/00113

01. Herrington L, Myer G, Horsley I. Task based rehabilitation protocol
    for elite athletes following anterior cruciate ligament reconstruction:
    a clinical commentary. Phys Ther Sport. 2013;14(4):188-198.
    doi:10.1016/j.ptsp.2013.08.001

01. Hewett TE, Bates NA. Preventive biomechanics: a paradigm shift
    with a translational approach to injury prevention. Am J Sports
    Med. 2017;45(11):2654-2664. doi:10.1177/0363546516686080

01. Kalema RN, Duhig SJ, Williams MD, Donaldson A, Shield AJ. Sprinting technique and hamstring strain injuries: a concept mapping
    study. J Sci Med Sport. 2022;25(3):209-215. doi:10.1016/j.jsams
    .2021.09.007

01. Kalkhoven JT, Watsford M. Mechanical contributions to muscle
    injury: implications for athletic injury risk mitigation. Published online
    April 9, 2020. SportRxiv. doi:10.31236/osf.io/a5um4

01. Kenneally-Dabrowski C, Brown NAT, Warmenhoven J, et al. Late
    swing running mechanics influence hamstring injury susceptibility in
    elite rugby athletes: a prospective exploratory analysis. J Biomech.
    2019;92:112-119. doi:10.1016/j.jbiomech.2019.05.037

01. Koo TK, Li MY. A guideline of selecting and reporting intraclass correlation coefficients for reliability research. J Chiropr Med.
    2016;15(2):155-163. doi:10.1016/j.jcm.2016.02.012

01. Krosshaug T, Nakamae A, Boden B, et al. Estimating 3D joint kinematics from video sequences of running and cutting
    maneuvers—assessing the accuracy of simple visual inspection.
    Gait Posture. 2007;26(3):378-385. doi:10.1016/j.gaitpost.2006
    .10.010

01. Landis JR, Koch GG. The measurement of observer agreement for
    categorical data. Biometrics. 1977;33(1):159-174.

01. Macdonald B, McAleer S, Kelly S, Chakraverty R, Johnston M, Pollock N. Hamstring rehabilitation in elite track and field athletes: applying the British Athletics Muscle Injury Classification in clinical
    practice. Br J Sports Med. 2019;53(23):1464-1473. doi:10.1136/
    bjsports-2017-098971

01. Mann R, Murphy A. The Mechanics of Sprinting and Hurdling: 2015
    Edition. CreateSpace Independent Publishing Platform; 2015.

01. McKay AKA, Stellingwerff T, Smith ES, et al. Defining training and
    performance caliber: a participant classification framework. Int J
    Sports Physiol Perform. 2022;17(2):317-331. doi:10.1123/
    ijspp.2021-0451

01. McMahon JJ, Ripley NJ, Comfort P. Force plate-derived countermovement jump normative data and benchmarks for professional
    rugby league players. Sensors (Basel). 2022;22(22):8669.
    doi:10.3390/s22228669

01. McMillan S, Pfaff D. Kinogram Method Ebook ALTIS (ALTIS). 2018.
    Accessed March 2020. <https://altis.world/kinogram-method-ebook/>

01. Mendiguchia J, Castan˜ o-Zambudio A, Jime´ nez-Reyes P, et al. Can
    we modify maximal speed running posture? Implications for performance and hamstring injury management. Int J Sports Physiol Perform. 2022;17(3):374-383. doi:10.1123/ijspp.2021-0107

01. Mendiguchia J, Gonzalez De la Flor A, Mendez-Villanueva A, Morin
    JB, Edouard P, Garrues MA. Training-induced changes in anterior
    pelvic tilt: potential implications for hamstring strain injuries management. J Sports Sci. 2021;39(7):760-767. doi:10.1080/02640414

.2020.1845439

35. Nagahara R, Matsubayashi T, Matsuo A, Zushi K. Kinematics of transition during human accelerated sprinting. Biol Open. 2014;3(8):689699. doi:10.1242/bio.20148284

01. Onate J, Cortes N, Welch C, Van Lunen BL. Expert versus novice
    interrater reliability and criterion validity of the Landing Error Scoring
    System. J Sport Rehabil. 2010;19(1):41-56. doi:10.1123/jsr.19.1.41

01. Padua DA, DiStefano LJ, Beutler AI, de la Motte SJ, DiStefano MJ,
    Marshall SW. The Landing Error Scoring System as a screening
    tool for an anterior cruciate ligament injury-prevention program in
    elite-youth soccer athletes. J Athl Train. 2015;50(6):589-595.
    doi:10.4085/1062-6050-50.1.10

01. Padua DA, Marshall SW, Boling MC, Thigpen CA, Garrett WE Jr,
    Beutler AI. The Landing Error Scoring System (LESS) is a valid and
    reliable clinical assessment tool of jump-landing biomechanics: the
    JUMP-ACL study. Am J Sports Med. 2009;37(10):1996-2002.
    doi:10.1177/0363546509343200

01. Piovesana A, Senior G. How small is big: sample size and skewness.
    Assessment. 2018;25(6):793-800. doi:10.1177/1073191116669784

01. Pipkin A, Kotecki K, Hetzel S, Heiderscheit B. Reliability of a qualitative video analysis for running. J Orthop Sports Phys Ther.
    2016;46(7):556-561. doi:10.2519/jospt.2016.6280

01. Schache AG, Wrigley TV, Baker R, Pandy MG. Biomechanical
    response to hamstring muscle strain injury. Gait Posture.
    2009;29(2):332-338. doi:10.1016/j.gaitpost.2008.10.054

01. Schuermans J, Danneels L, Van Tiggelen D, Palmans T, Witvrouw E.
    Proximal neuromuscular control protects against hamstring injuries in
    male soccer players: a prospective study with electromyography
    time-series analysis during maximal sprinting. Am J Sports Med.
    2017;45(6):1315-1325. doi:10.1177/0363546516687750

01. Schuermans J, Van Tiggelen D, Palmans T, Danneels L, Witvrouw E.
    Deviating running kinematics and hamstring injury susceptibility in
    male soccer players: cause or consequence? Gait Posture.
    2017;57:270-277. doi:10.1016/j.gaitpost.2017.06.268

01. Sides DL. Kinematics and Kinetics of Maximal Velocity Sprinting and
    Specificity of Training in Elite Athletes. Dissertation. University of Salford; 2015.

01. Turner AN, Jones B, Stewart P, et al. Total score of athleticism: holistic athlete profiling to enhance decision-making. Strength Conditioning J. 2019;41(6):91-101. doi:10.1519/ssc.0000000000000506

01. Weeks BK, Carty CP, Horan SA. Kinematic predictors of single-leg
    squat performance: a comparison of experienced physiotherapists
    and student physiotherapists. BMC Musculoskelet Disord.
    2012;13:207. doi:10.1186/1471-2474-13-207

01. Whatman C, Hing W, Hume P. Physiotherapist agreement when visually rating movement quality during lower extremity functional
    screening tests. Phys Ther Sport. 2012;13(2):87-96. doi:10.1016/
    j.ptsp.2011.07.001

01. Whatman C, Hume P, Hing W. The reliability and validity of physiotherapist visual rating of dynamic pelvis and knee alignment in young
    athletes. Phys Ther Sport. 2013;14(3):168-174. doi:10.1016/
    j.ptsp.2012.07.001

For reprints and permission queries, please visit Sage’s Web site at <http://www.sagepub.com/journals-permissions>
